@@ -53,10 +53,10 @@ class Project(project.Project):
                 'B description_format BDF, B description BD, B load_left BC, '
                 'B title BT, B modification_date BMD, '
                 'B load C, T? tags B, T name TN, B done_in V?, V num VN, '
-                'B created_by U?, U login UL, B concerns P, P eid %s'
-                ) % (fixed_orderby_rql(self.sort_defs),
-                     limit and ' LIMIT %s' % limit or '',
-                     self.eid)
+                'B created_by U?, U login UL, B concerns P, P eid %%(x)s'
+                % (fixed_orderby_rql(self.sort_defs),
+                   limit and ' LIMIT %s' % limit or ''),
+                {'x': self.eid})
 
 
 class ProjectIFTIndexableAdapter(IFTIndexableAdapter):
@@ -132,9 +132,9 @@ class Version(version.Version):
                 'GROUPBY B,TT,PR,S,C,AC,U,TI,D,DF,V %s '
                 'WHERE B type TT, B priority PR, B load_left AC, B load C, '
                 'B in_state S, T? tags B, T name TN, B created_by U?,'
-                'B done_in V, V eid %s, '
+                'B done_in V, V eid %%(x)s, '
                 'B title TI, B description D, B description_format DF'
-                % (fixed_orderby_rql(self.sort_defs), self.eid))
+                % fixed_orderby_rql(self.sort_defs), {'x': self.eid})
 
     defects_rql_nb_displayed_cols = 5
     def defects_rql(self):
@@ -142,9 +142,9 @@ class Version(version.Version):
         return ('Any B,S,V,U,group_concat(TN), BT,BD,BDF '
                 'GROUPBY B,S,V,U,BT,BD,BDF ORDERBY S '
                 'WHERE B in_state S, T? tags B, T name TN, B created_by U?,'
-                'B done_in V?, B appeared_in X, X eid %s, '
-                'B title BT, B description BD, B description_format BDF'
-                % self.eid)
+                'B done_in V?, B appeared_in X, X eid %(x)s, '
+                'B title BT, B description BD, B description_format BDF',
+                {'x': self.eid})
 
 
 class VersionIMileStoneAdapter(version.VersionIMileStoneAdapter):
