@@ -110,13 +110,9 @@ class SetTicketLoadLeft(Hook):
     __select__ = Hook.__select__ & is_instance('Ticket',)
 
     def __call__(self):
-        edited = self.entity.edited_attributes
-        has_load_left = 'load_left' in edited
+        edited = self.entity.cw_edited
         if 'load' in edited and self.entity.load_left is None:
-            self.entity.load_left = self.entity['load']
-        elif not has_load_left and 'load_left' in edited:
-            # cleanup, this may cause undesired changes
-            del self.entity['load_left']
+            edited['load_left'] = edited['load']
 
 
 class SetNosyListBeforeAddComment(Hook):
@@ -168,8 +164,8 @@ class TicketProgressHook(Hook):
     events = ('after_update_entity', )
 
     def __call__(self):
-        if 'load' in self.entity.edited_attributes or \
-               'load_left' in self.entity.edited_attributes:
+        if 'load' in self.entity.cw_edited or \
+               'load_left' in self.entity.cw_edited:
             try:
                 self.entity.done_in[0].update_progress()
             except IndexError:
