@@ -1,4 +1,5 @@
 from datetime import timedelta
+from cubicweb import devtools # needed to ensure cubes.tracker is importable
 
 from cubes.tracker.testutils import BaseMSTC, ms_test_init
 repo2, cnx2, repo3, cnx3, eids = ms_test_init()
@@ -6,7 +7,7 @@ repo2, cnx2, repo3, cnx3, eids = ms_test_init()
 class ThreeSourcesTC(BaseMSTC):
     def test_projects_interested_in(self):
         rset = self.execute('Any P,N WHERE P name N, X interested_in P, X eid %(x)s', {'x': self.session.user.eid})
-        self.assertEquals(len(rset), 3)
+        self.assertEqual(len(rset), 3)
 
     def test_nonregr2(self):
         self.execute('INSERT Card X: X title "test1", X test_case_of P WHERE P eid %(x)s', {'x': self.ip1eid})
@@ -16,7 +17,7 @@ class ThreeSourcesTC(BaseMSTC):
         self.fire_transition(self.ip1t1eid, 'start')
         self.commit()
         ip1v1 = self.execute('Any X WHERE X eid %(x)s', {'x': self.ip1v1eid}).get_entity(0, 0)
-        self.assertEquals(ip1v1.cw_adapt_to('IWorkflowable').state, 'dev')
+        self.assertEqual(ip1v1.cw_adapt_to('IWorkflowable').state, 'dev')
 
     def test_nonregr6(self):
         # XXX monkey patch of sqlgenerator needed since sqlite needs distinct
@@ -27,15 +28,15 @@ class ThreeSourcesTC(BaseMSTC):
         try:
             rset = self.execute('Any E,F ORDERBY F WHERE X has_text %(text)s, X in_state E, E name F',
                                 {'text': 'extern'})
-            self.assertEquals(len(rset), 2)
+            self.assertEqual(len(rset), 2)
             rset = self.execute('Any E,F ORDERBY F WHERE X has_text %(text)s, X in_state E, E name F',
                                 {'text': 'intern'})
-            self.assertEquals(len(rset), 3)
+            self.assertEqual(len(rset), 3)
             rset = self.execute('Any E,F ORDERBY F WHERE X has_text %(text)s, X in_state E, E name F',
                                 {'text': 'project'})
             # 3 projects in two external sources, 3 projects + 2 tickets in internal source
-            self.assertEquals(len(rset), 8)
-            self.assertEquals(set(sn for s, sn in rset), set(('active development', 'open')))
+            self.assertEqual(len(rset), 8)
+            self.assertEqual(set(sn for s, sn in rset), set(('active development', 'open')))
         finally:
             for repo in (self.repo, repo2, repo3):
                 sqlgen = repo.system_source._rql_sqlgen
@@ -49,7 +50,7 @@ class ThreeSourcesTC(BaseMSTC):
                             'WHERE B type TT, B priority PR, B in_state S, B creation_date CD, B load C, T? tags B, T name TN, B done_in V?, V num VN, B concerns P, P eid %s'
                             % self.ip1eid)
         rset.rows[0][4] = 'STATE'
-        self.assertEquals(rset.rows, [[self.ip1t1eid, u'bug', timedelta(0), u'normal', 'STATE', None, self.ip1v1eid, u'']])
+        self.assertEqual(rset.rows, [[self.ip1t1eid, u'bug', timedelta(0), u'normal', 'STATE', None, self.ip1v1eid, u'']])
 
 
 if __name__ == '__main__':
