@@ -24,34 +24,34 @@ class ProjectTC(TrackerBaseTC):
 
     def test_tickets_rql(self):
         self.execute(self.cubicweb.active_tickets_rql()) # just check rql validity
-        self.execute(self.cubicweb.tickets_rql()) # just check rql validity
+        self.execute(*self.cubicweb.tickets_rql()) # just check rql validity
 
     def test_download_box(self):
         req = self.request()
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
         self.assertRaises(NoSelectableObject,
-                          self.vreg['boxes'].select, 'download_box', req, rset=rset)
+                          self.vreg['ctxcomponents'].select, 'download_box', req, rset=rset)
         self.execute('SET X downloadurl "ftp://ftp.logilab.org/pub/cubicweb/" WHERE X is Project')
         req = self.request()
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
         self.assertRaises(NoSelectableObject,
-                          self.vreg['boxes'].select, 'download_box', req, rset=rset)
+                          self.vreg['ctxcomponents'].select, 'download_box', req, rset=rset)
         v = self.create_version('0.0.0').get_entity(0, 0)
         self.commit()
         req = self.request()
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
         self.assertRaises(NoSelectableObject,
-                          self.vreg['boxes'].select, 'download_box', req, rset=rset)
+                          self.vreg['ctxcomponents'].select, 'download_box', req, rset=rset)
         v.cw_adapt_to('IWorkflowable').change_state('published')
         req = self.request()
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
-        self.assertIsInstance(self.vreg['boxes'].select('download_box', req, rset=rset),
+        self.assertIsInstance(self.vreg['ctxcomponents'].select('download_box', req, rset=rset),
                               boxes.ProjectDownloadBox)
         self.commit()
         self.login('anon')
         req = self.request()
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
-        self.assertIsInstance(self.vreg['boxes'].select('download_box', req, rset=rset),
+        self.assertIsInstance(self.vreg['ctxcomponents'].select('download_box', req, rset=rset),
                               boxes.ProjectDownloadBox)
 
     def test_possible_actions(self):
@@ -236,22 +236,22 @@ class VersionTC(TrackerBaseTC):
         req = self.request()
         rset = req.execute('Any X WHERE X is Version, X num "0.0.0"')
         self.assertRaises(NoSelectableObject,
-                          self.vreg['boxes'].select, 'download_box', req, rset=rset)
+                          self.vreg['ctxcomponents'].select, 'download_box', req, rset=rset)
         self.execute('SET X downloadurl "ftp://ftp.logilab.org/pub/cubicweb/" WHERE X is Project')
         req = self.request()
         rset = req.execute('Any X WHERE X is Version, X num "0.0.0"')
         self.assertRaises(NoSelectableObject,
-                          self.vreg['boxes'].select, 'download_box', req, rset=rset)
+                          self.vreg['ctxcomponents'].select, 'download_box', req, rset=rset)
         self.v.cw_adapt_to('IWorkflowable').change_state('published')
         req = self.request()
         rset = req.execute('Any X WHERE X is Version, X num "0.0.0"')
-        self.assertIsInstance(self.vreg['boxes'].select('download_box', req, rset=rset),
+        self.assertIsInstance(self.vreg['ctxcomponents'].select('download_box', req, rset=rset),
                               idownloadable.DownloadBox)
         self.commit()
         self.login('anon')
         req = self.request()
         rset = req.execute('Any X WHERE X is Version, X num "0.0.0"')
-        self.assertIsInstance(self.vreg['boxes'].select('download_box', req, rset=rset),
+        self.assertIsInstance(self.vreg['ctxcomponents'].select('download_box', req, rset=rset),
                               idownloadable.DownloadBox)
 
 class TicketTC(TrackerBaseTC):
@@ -270,14 +270,14 @@ class TicketTC(TrackerBaseTC):
         self.t1.set_attributes(load=2)
         self.t1.cw_adapt_to('IWorkflowable').change_state('deprecated')
         self.commit()
-        self.t1.pop('load', None)
+        self.t1.cw_attr_cache.pop('load', None)
         self.assertEqual(self.t1.load, 0)
 
     def test_load_after_state_changed_rejected(self):
         self.t1.set_attributes(load=2)
         self.t1.cw_adapt_to('IWorkflowable').change_state('rejected')
         self.commit()
-        self.t1.pop('load', None)
+        self.t1.cw_attr_cache.pop('load', None)
         self.assertEqual(self.t1.load, 0)
 
     def test_auto_set_load_left_1(self):
@@ -287,10 +287,10 @@ class TicketTC(TrackerBaseTC):
 
     def test_auto_set_load_left_2(self):
         self.execute('SET X load 1 WHERE X eid %(x)s', {'x': self.t1.eid})
-        self.t1.pop('load_left', None)
+        self.t1.cw_attr_cache.pop('load_left', None)
         self.assertEqual(self.t1.load_left, 1)
         self.execute('SET X load 2 WHERE X eid %(x)s', {'x': self.t1.eid})
-        self.t1.pop('load_left', None)
+        self.t1.cw_attr_cache.pop('load_left', None)
         self.assertEqual(self.t1.load_left, 1)
 
     def test_modification_date_after_comment_added(self):
