@@ -19,7 +19,7 @@ class NotificationTC(TrackerBaseTC):
                      'WHERE B title "one more"')
         b.set_attributes(priority=u'important')
         self.commit()
-        self.assertEquals([re.sub('#\d+', '#EID', e.subject) for e in MAILBOX],
+        self.assertEqual([re.sub('#\d+', '#EID', e.subject) for e in MAILBOX],
                           ['[data] New Project: hop',
                            '[data] New Project: hop', # see below
                            '[hop] New Ticket #EID: one more',
@@ -27,20 +27,20 @@ class NotificationTC(TrackerBaseTC):
                            ])
         # test that for new project, recipients are the nosy list (eg creator)
         # *and* default recipients
-        self.assertEquals(MAILBOX[0].recipients, ['admin@cwo'])
-        self.assertEquals(MAILBOX[1].recipients, self.config['default-dest-addrs'])
+        self.assertEqual(MAILBOX[0].recipients, ['admin@cwo'])
+        self.assertEqual(MAILBOX[1].recipients, self.config['default-dest-addrs'])
         # but only nosy list for tickets / comments
-        self.assertEquals(MAILBOX[2].recipients, ['admin@cwo'])
-        self.assertEquals(MAILBOX[3].recipients, ['admin@cwo'])
+        self.assertEqual(MAILBOX[2].recipients, ['admin@cwo'])
+        self.assertEqual(MAILBOX[3].recipients, ['admin@cwo'])
         # check that other notification when project isn't being created are
         # using regulary nosy list recipients
         MAILBOX[:] = ()
         p.cw_adapt_to('IWorkflowable').fire_transition('temporarily stop development')
         self.commit()
-        self.assertEquals([re.sub('#\d+', '#EID', e.subject) for e in MAILBOX],
+        self.assertEqual([re.sub('#\d+', '#EID', e.subject) for e in MAILBOX],
                           ['[hop] project is now in state "asleep"',
                            ])
-        self.assertEquals(MAILBOX[0].recipients, ['admin@cwo'])
+        self.assertEqual(MAILBOX[0].recipients, ['admin@cwo'])
 
     def test_nosy_list_propagation(self):
         self.create_user('logilabien')
@@ -49,12 +49,12 @@ class NotificationTC(TrackerBaseTC):
         self.commit()
         ticket = self.create_ticket('ticket').get_entity(0, 0)
         self.commit()
-        self.assertEquals(len(MAILBOX), 2)
+        self.assertEqual(len(MAILBOX), 2)
         MAILBOX.sort(key=lambda x: x.recipients)
-        self.assertEquals(MAILBOX[0].subject, '[cubicweb] New Ticket #%s: ticket' % ticket.eid)
-        self.assertEquals(MAILBOX[0].recipients, ['admin@cwo'])
-        self.assertEquals(MAILBOX[1].subject, '[cubicweb] New Ticket #%s: ticket' % ticket.eid)
-        self.assertEquals(MAILBOX[1].recipients, ['logilabien@logilab.org'])
+        self.assertEqual(MAILBOX[0].subject, '[cubicweb] New Ticket #%s: ticket' % ticket.eid)
+        self.assertEqual(MAILBOX[0].recipients, ['admin@cwo'])
+        self.assertEqual(MAILBOX[1].subject, '[cubicweb] New Ticket #%s: ticket' % ticket.eid)
+        self.assertEqual(MAILBOX[1].recipients, ['logilabien@logilab.org'])
 
 
 if __name__ == '__main__':
