@@ -7,10 +7,12 @@
 __docformat__ = "restructuredtext en"
 _ = unicode
 
-from cubicweb.web import uicfg
+from cubicweb.selectors import is_instance
+from cubicweb.web import uicfg, facet
 from cubicweb.web.views.urlrewrite import (
     SimpleReqRewriter, SchemaBasedRewriter, rgx, build_rset)
 
+
 class ForgeURLRewriter(SchemaBasedRewriter):
     """handle path with the form::
 
@@ -97,3 +99,9 @@ _abaa.tag_subject_of(('Ticket', 'attachment', 'File'), True)
 
 _abaa.tag_object_of(('Ticket', 'filed_under', 'Folder'), False)
 _abaa.tag_object_of(('Version', 'filed_under', 'Folder'), False)
+
+class TicketHasAttachmentFacet(facet.HasRelationFacet):
+    __regid__ = 'forge.attachment-facet'
+    __select__ = facet.HasRelationFacet.__select__ & is_instance('Ticket')
+    rtype = 'attachment'
+    role = 'subject'
