@@ -1,13 +1,13 @@
 """some additional tabs for Ticket entities
 
 :organization: Logilab
-:copyright: 2006-2009 LOGILAB S.A. (Paris, FRANCE), license is LGPL.
+:copyright: 2006-2010 LOGILAB S.A. (Paris, FRANCE), license is LGPL.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
 _ = unicode
 
-from cubicweb.selectors import one_line_rset, implements
+from cubicweb.selectors import one_line_rset, is_instance
 from cubicweb.web import component
 from cubicweb.web.views import tabs
 
@@ -15,7 +15,7 @@ from cubicweb.web.views import tabs
 class TicketTestCardVComponent(component.RelatedObjectsVComponent):
     """display project's test cards"""
     __regid__ = 'tickettests'
-    __select__ = component.RelatedObjectsVComponent.__select__ & implements('Ticket')
+    __select__ = component.RelatedObjectsVComponent.__select__ & is_instance('Ticket')
 
     rtype = 'test_case_for'
     target = 'subject'
@@ -28,7 +28,7 @@ class TicketTestCardVComponent(component.RelatedObjectsVComponent):
 class TicketScreenshotsView(tabs.EntityRelationView):
     """display ticket's screenshots """
     __regid__ = 'ticketscreenshots'
-    __select__ = one_line_rset() & tabs.EntityRelationView.__select__ & implements('Ticket')
+    __select__ = one_line_rset() & tabs.EntityRelationView.__select__ & is_instance('Ticket')
 
     rtype = 'attachment'
     target = 'object'
