@@ -8,6 +8,7 @@ __docformat__ = "restructuredtext en"
 _ = unicode
 
 from cubicweb.selectors import is_instance
+from cubicweb.view import EntityView
 from cubicweb.web import uicfg, component
 
 from cubes.tracker.views import version as tracker
@@ -16,20 +17,21 @@ _pvs = uicfg.primaryview_section
 for attr in ('progress_target', 'progress_done', 'progress_todo'):
     _pvs.tag_attribute(('Version', attr), 'hidden')
 
-class VersionBurndownChartVComponent(component.EntityVComponent):
-    __regid__ = 'versionburndown'
-    __select__ = component.EntityVComponent.__select__ & is_instance('Version')
-    rql = ('Any X,CD,L,LL where X load L, X load_left LL, '
-           'X creation_date CD, X done_in V, V eid %s')
+tracker.VersionPrimaryView.tabs.append(_('forge.version.burndown_tab'))
+
+class VersionBurndownChartTab(EntityView):
+    __regid__ = 'forge.version.burndown_tab'
+    __select__ = EntityView.__select__ & is_instance('Version')
+    rql = ('Any X,CD,L,LL WHERE X load L, X load_left LL, '
+           'X creation_date CD, X done_in V, V eid %(x)s')
 
     def cell_call(self, row, col, view=None):
         version = self.cw_rset.entities().next()
         alt = self._cw._('Burn Down Chart')
         self.w('<h3>%s</h3>' % alt)
-        # the following rql is useful to detect Ticket which is
-        # created directly with a done state (validation pending,
-        # resolved, deprecated or rejected). In this case, graph is
-        # probably wrong.
+        # the following rql is useful to detect ticket created directly in a
+        # done state (validation pending, resolved, deprecated or rejected). In
+        # this case, graph is probably wrong.
         ticketcls = self._cw.vreg['etypes'].etype_class('Ticket')
         rset = self._cw.execute(
             'Any T GROUPBY T  WHERE T done_in V, V eid %%(v)s, '
@@ -40,7 +42,7 @@ class VersionBurndownChartVComponent(component.EntityVComponent):
             self.w(u'<div class="needsvalidation">%s</div>'
                    % self._cw._("Some tickets don't have a regular workflow, "
                                 "the graph may be wrong."))
-        tickets_rset = self._cw.execute(self.rql % self.cw_rset[row][col])
+        tickets_rset = self._cw.execute(self.rql, {'x': self.cw_rset[row][col]})
         if tickets_rset:
             self.wview('burndown_chart', tickets_rset, width=800, height=500)
 
